#!/bin/bash

clear
echo ""
echo "This tool enables Kaspersky Endpoint Security for Mac trace logs."
echo ""


if [ `grep -c 'ProductVersion\">\(10\.\|11\.\)' /Library/Application\ Support/Kaspersky\ Lab/KAV/Binaries/config.xml 2>/dev/null` -ne 1 ]; then
        echo "This tool is compatible only with Kaspersky Endpoint Security 10.* and  11.* for Mac"
        echo "Application is not installed or wrong version detected."
        exit 1
fi

KAVPID=$(ps -axwo pid,command | grep -v grep | grep "KAV/Binaries/kav" | awk '{print $1}')
if [ "x$KAVPID" != "x" ]
then
        echo "Attention! This tool cannot run while Kaspersky Endpoint Security for Mac is running."
	echo "Please exit Kaspersky Endpoint Security for Mac first and run this tool again."
        echo ""
        exit 1;
fi

if [ `whoami | grep -c root` -ne 1 ]; then
       echo "Please run from root user ('sudo -s')."
       exit 1 
fi


sed 's/TraceFileEnable\">0/TraceFileEnable\">1/' < /Library/Application\ Support/Kaspersky\ Lab/KAV/Binaries/config.xml > /Library/Application\ Support/Kaspersky\ Lab/KAV/Binaries/config__tmp.xml
confignum=`wc -m /Library/Application\ Support/Kaspersky\ Lab/KAV/Binaries/config.xml | awk '{ print $1}'`
tmpnum=`wc -m /Library/Application\ Support/Kaspersky\ Lab/KAV/Binaries/config__tmp.xml | awk '{ print $1}'`

if [ $confignum -eq $tmpnum ];
then
	mv /Library/Application\ Support/Kaspersky\ Lab/KAV/Binaries/config__tmp.xml /Library/Application\ Support/Kaspersky\ Lab/KAV/Binaries/config.xml
	echo ""
	echo "Application tracing enabled. Trace files location:"
	echo "/Library/Logs/Kaspersky Lab/*"
	echo "/Users/<username>/Library/Logs/Kaspersky Lab/*.log";
	echo ""
else
	echo "Failed to enable application traces"
        exit 1
fi



echo ""
echo "Please start Kaspersky Endpoint Security for Mac."

exit 0
